<a id="autonomy.analyse.handlers"></a>

# autonomy.analyse.handlers

Analyse handlers.

<a id="autonomy.analyse.handlers.load_handler_module_from_skill_path"></a>

#### load`_`handler`_`module`_`from`_`skill`_`path

```python
def load_handler_module_from_skill_path(skill_path: Path) -> types.ModuleType
```

Resolve handler path to current workind directory.

<a id="autonomy.analyse.handlers.check_handlers"></a>

#### check`_`handlers

```python
def check_handlers(config_file: Path, common_handlers: List[str]) -> None
```

Check handlers

